local myfiles: dir "data\raw_data" files "*.dta"

foreach file of local myfiles {
//BUILD STRINGS TO NAME NEW DATASETS
local subfile = subinstr("`file'"," lapop americasbarometer ","",.)
local subfile = subinstr("`subfile'","-17 v1.0_w","",.)
local subfile = subinstr("`subfile'"," rev1_w","",.)
local subfile = subinstr("`subfile'"," v3.0_w","",.)
local subfile = subinstr("`subfile'"," v1.0_w","",.)
local subfile = subinstr("`subfile'"," _v1.1_w","",.)
local subfile = subinstr("`subfile'","_lapop_americasbarometer_","",.)
local subfile = subinstr("`subfile'","_v1.1_w","",.)
local subfile = subinstr("`subfile'","_lapop_americasbarometer ","",.)
local subfile = subinstr("`subfile'"," data set approved v3","",.)
local subfile = subinstr("`subfile'"," data set  approved v3","",.)
local subfile = subinstr("`subfile'"," v1.0 w","",.)
local subfile = subinstr("`subfile'"," v3.0_free","",.)
local subfile = subinstr("`subfile'",".dta","",.)

//OPEN DATA FILE
use "data\raw_data/`file'", clear
disp "`subfile'"

if "`subfile'"!="americasbarometer grand merge 2004-2014"{
local year = substr("`subfile'",-4,4)
capture drop year
gen year = `year'

forvalues i=0/9{
local subfile = subinstr("`subfile'","`i'","",.)
}
local subfile="`subfile'`year'.dta"
save "data\to_stack/`subfile'", replace
}
else{
save "data\merge_2010-2014.dta", replace
}
}
//OPEN MERGE FILE
use "data\merge_2010-2014.dta", clear
drop if year < 2010
drop if pais>22
local myfiles: dir "data\to_stack" files "*.dta"
foreach file of local myfiles {
append using "data\to_stack/`file'", force 
}
replace year=2016 if year==2017

**Outcome Variables
recode ls3 pn4 (1=4) (2=3) (3=2) (4=1) (*=.), gen(life_sat dem_sat)
replace life_sat = (life_sat-1)/3
replace dem_sat = (dem_sat -1)/3
label var life_sat "Life Satisfaction (0-1)"
label var dem_sat "Satisfaction w /Democracy (0-1)"
gen pol_trust = (b2-1)/6
label var pol_trust "Respect for Pol. Institutions (0-1)"
gen ext_eff= (eff1-1)/6
label var ext_eff "External Efficacy (0-1)"
recode vb2 (1=1) (2=0) (*=.), gen(voted)
label var voted "Voted in Presidential Elections (1 = yes; 0 = no)"

recode colorr (12/.=.)
replace colorr=(colorr-1)/10
label var colorr "Pigment Darkness (0-1)"


recode q1 (2=1) (1=0), gen(female)
label var female "Female (1=yes)"
gen age=q2
gen age2=age^2/100
label var age "Age (in years)"
label var age2 "Age-squared/100"

recode r5 (0=0) (1/3=1) (*=.)
egen wealth=rmean(r1 r3 r4 r4a r5-r7 r12 r14 r15)
replace wealth = wealth
label var wealth "Material Wealth (0-1)"
replace ed = ed/18
label var ed "Schooling (0-1)"

gen ethnicity = etid
label var ethnicity "ethnicity"
recode ethnicity (1=1) (2=2) (3=3) (4=4) (5=5) (*=6)
label define ethnicity 1 "White" 2 "Mestizo" 3 "Indigenous" 4 "Black" 5 "Mullatto" 6 "Other Race/Ethnicity" 
label values ethnicity ethnicity
tab ethnicity, gen(eth_)
drop eth_1
label var eth_2 "Mestizo (1=yes)"
label var eth_3 "Indigenous (1=yes)"
label var eth_4 "Black (1=yes)"
label var eth_5 "Mullatto (1=yes)"
label var eth_6 "Other Race/Ethnicity (1=yes)"


**country
egen country = group(pais)
label define country 1 "Mexico" 2"Guatemala" 3"El Salvador" 4"Honduras" 5"Nicaragua" 6"Costa Rica" 7 "Panama" 8 "Colombia" 9 "Ecuador" 10 "Bolivia" 11 "Peru" 12 "Paraguay" 13 "Uruguay" 14 "Brazil" 15 "Venezuela" 16 "Argentina" 17 "Dominican Republic" 18 "Haiti" 
label values country country
tab country, gen(ctry_)
forvalues i=1/18{
local label : variable label ctry_`i'
local label = subinstr("`label'","country==","",.)
label var ctry_`i' "`label'"
}

**fill in weights of 1 for argentina and venezuela 2010
replace wt=1 if wt==.
//generate weight so each country given same weight
qui count
local avg_n_cty=r(N)/18
gen cty_wt=0
forvalues i = 1/18{
qui count if country==`i'
replace cty_wt=`avg_n_cty'/r(N) if country==`i'
}
gen full_wt=cty_wt*wt
label var full_wt "Weight: Country Ns Equal; Nationally Representative"
**year indicators
tab year, gen(year_)
drop year_1
rename year_2 yr2012
rename year_3 yr2014
rename year_4 yr2016

label var yr2012 "2012 (1=yes)"
label var yr2014 "2014 (1=yes)"
label var yr2016 "2016/2017 (1=yes)"
//drop if missing demographics and/or pigment measure
qui reg colorr female age age2 ed wealth eth_* yr2012 yr2014 yr2016 
keep if e(sample)
save "data\full_data.dta", replace
